@@ -330,9 +330,15 @@ dmapd_module_unload (GTypeModule *module)
 	return TRUE;
 }
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (AvMetaReaderGst,
+                                av_meta_reader_gst,
+                                TYPE_AV_META_READER,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (AvMetaReaderGst))
+
 static void av_meta_reader_gst_init (AvMetaReaderGst *reader)
 {
-	reader->priv = AV_META_READER_GST_GET_PRIVATE (reader);
+	reader->priv = av_meta_reader_gst_get_instance_private (reader);
 
 	reader->priv->loop       = g_main_loop_new (NULL, FALSE);
 	reader->priv->discoverer = NULL;
@@ -350,9 +356,3 @@ static void av_meta_reader_gst_class_init (AvMetaReaderGstClass *klass)
 	av_meta_reader_class->read = _read;
 	av_meta_reader_class->get_option_group = _get_option_group;
 }
-
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (AvMetaReaderGst,
-                                av_meta_reader_gst,
-                                TYPE_AV_META_READER,
-                                0,
-                                G_ADD_PRIVATE_DYNAMIC (AvMetaReaderGst))
