@@ -381,10 +381,16 @@ dmapd_module_unload (GTypeModule *module)
 	return TRUE;
 }
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (AvRenderGst,
+                                av_render_gst,
+                                TYPE_AV_RENDER,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (AvRenderGst))
+
 static void
 av_render_gst_init (AvRenderGst *render)
 {
-	render->priv = AV_RENDER_GST_GET_PRIVATE (render);
+	render->priv = av_render_gst_get_instance_private (render);
 
 	render->priv->loop = g_main_loop_new (NULL, FALSE);
 	render->priv->song_list = NULL;
@@ -554,9 +560,3 @@ av_render_gst_class_init (AvRenderGstClass *klass)
 							    DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP,
 							    G_PARAM_READWRITE));
 }
-
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (AvRenderGst,
-                                av_render_gst,
-                                TYPE_AV_RENDER,
-                                0,
-                                G_ADD_PRIVATE_DYNAMIC (AvRenderGst))
