@@ -396,10 +396,16 @@ done:
 	return ok;
 }
 
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (DbBuilderGDir,
+                                db_builder_gdir,
+                                TYPE_DB_BUILDER,
+                                0,
+                                G_ADD_PRIVATE_DYNAMIC (DbBuilderGDir))
+
 static void
 db_builder_gdir_init (DbBuilderGDir *builder)
 {
-        builder->priv = DB_BUILDER_GDIR_GET_PRIVATE (builder);
+        builder->priv = db_builder_gdir_get_instance_private (builder);
 
 	builder->priv->monitor_list     = NULL;
 	builder->priv->creates_underway = g_hash_table_new_full(g_str_hash, g_str_equal, free, NULL);
@@ -468,12 +474,6 @@ dmapd_module_unload (GTypeModule *module)
 {
 }
 
-G_DEFINE_DYNAMIC_TYPE_EXTENDED (DbBuilderGDir,
-                                db_builder_gdir,
-                                TYPE_DB_BUILDER,
-                                0,
-                                G_ADD_PRIVATE_DYNAMIC (DbBuilderGDir))
-
 #ifdef HAVE_CHECK
 
 Suite *db_test_builder_gdir_suite(void)
