@@ -23,6 +23,10 @@
 
 #include <libdmapsharing/dmap.h>
 
+#ifdef HAVE_CHECK
+#include <check.h>
+#endif
+
 #include "av-meta-reader.h"
 
 G_BEGIN_DECLS
@@ -50,7 +54,7 @@ GType dmapd_daap_record_get_type (void);
 
 
 DmapdDmapAvRecord *dmapd_daap_record_new (const char *location,
-                                          AVMetaReader *reader,
+                                          AvMetaReader *reader,
                                           GError **error);
 
 gint          dmapd_daap_record_get_id          (DmapAvRecord *record);
@@ -62,4 +66,8 @@ GInputStream *dmapd_daap_record_read            (DmapAvRecord *record,
 
 G_END_DECLS
 
+#ifdef HAVE_CHECK
+Suite *dmapd_test_daap_record_suite(void);
+#endif
+
 #endif
