@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __DMAPD_DPAP_RECORD_FACTORY
-#define __DMAPD_DPAP_RECORD_FACTORY
+#ifndef _DMAPD_DPAP_RECORD_FACTORY_H
+#define _DMAPD_DPAP_RECORD_FACTORY_H
 
 #include <libdmapsharing/dmap.h>
 
@@ -51,8 +51,11 @@ typedef struct {
 
 GType                  dmapd_dpap_record_factory_get_type (void);
 
-DmapRecord            *dmapd_dpap_record_factory_create   (DmapRecordFactory *factory, gpointer user_data);
-
-#endif /* __DMAPD_DPAP_RECORD_FACTORY */
+DmapRecord            *dmapd_dpap_record_factory_create(
+                            DmapRecordFactory *factory,
+                            gpointer user_data,
+                            GError **error);
 
 G_END_DECLS
+
+#endif
