@@ -415,7 +415,7 @@ static gboolean
 _read (PhotoMetaReader *reader, DmapImageRecord *record, const gchar *path, GError **error)
 {
 	g_assert (IS_PHOTO_META_READER (reader));
-	g_assert (IS_DMAP_IMAGE_RECORD (record));
+	g_assert (DMAP_IS_IMAGE_RECORD (record));
 	g_assert (NULL != path);
 
 	VipsObject *process;
